# Abstract Algebra 2 Definitions 

## Chapter 17

By a **ring** we mean a set $A$ with operations called addition and multiplication which satisfy the following axioms:

- $A$ with addition alone is an abelian group
- Multiplication is associative
- Multiplication is distributive over addition

Since $\langle A, + \rangle$ is an abelian group, there is in $A$ a neutral element for addition. This is called the **zero** element. Also, every element has an additive inverse called its **negative**.

If multiplication in a ring $A$ is commutative then we say that $A$ is a **commutative ring**.

If a ring $A$ has a neutral element for multiplication then we say that the neutral element is the **unity** of $A$.

If $A$ is a ring with unity, there may be elements in $A$ which have a multiplicative inverse. Such elements are said to be **invertible**.

If $A$ is a commutative ring with unity in which every nonzero element is invertible, then $A$ is called a **field**.

In any ring, a nonzero element $a$ is called a **divisor of zero** if there is a nonzero element $b$ in a ring such that the product $ab$ or $ba$ is equal to zero.

An **integral domain** is defined to be a commutative ring with unity that has the cancellation property. Another way of saying this is that an integral domain is a commutative ring with unity and has no zero divisors.

## Chapter 18

Let $A$ be a ring, and $B$ be a nonempty subset of $A$. $B$ is called a **subring** if it satisfies the following properties:

- Closed with respect to addition
- Closed with respect to negatives
- Closed with respect to multiplication

Let $B$ be a subring of $A$. We call $B$ an **ideal** of $A$ if $xb, bx \in B$ for all $b \in B$ and $x \in A$.

The **principle ideal generated by $a$**, denoted $\langle a \rangle$ is the subring defined by fixing an element $a$ in a subring $B$ of $A$ and multiplying all elements of $A$ by $a$.
$$
\langle a \rangle = \{ xa : x \in A \}
$$
A **homomorphism** from a ring $A$ to a ring $B$ is a function $f : A \to B$ satisfying the identities:
$$
f(x_1 + x_2 ) = f(x_1) + f(x_2) \\
f(x_1x_2) = f(x_1)f(x_2)
$$
If there is a homomorphism from $A$ onto $B$, we call $B$ a **homomorphic image** of $A$.

If $f$ is a homomorphism from a ring $A$ to a ring $B$, the **kernel** of $f$ is the set of all the elements of $A$ which are carried by $f$ onto the zero element of $B$. In symbols, the kernel of $f$ is the set
$$
K = \{x \in A: f(x) = 0\}
$$
If $A$ and $b$ are rings, an **isomorphism** from $A$ to $B$ is a homomorphism which is a one-to-one correspondence from $A$ to $B$. In other words, it is injective and surjective homomorphism. 

If there is an isomorphism from $A$ to $B$ we say that $A$ is **isomorphic** to $B$, and this fact is expressed by writing $A \cong B$.

## Chapter 19

Let $A$ be a ring, and $J$ an ideal of $A$. For any element $a \in A$, the symbol $J + a$ denotes the set of all sums $j + a$ as $a$ remains fixed and $j$ ranges over $J$. That is,
$$
J + a = \{j + a : j \in J\}
$$
$J + a$ is called a **coset** of $J$ in $A$.

Now think of the set which contains all cosets of $J$ in $A$. This set is conventionally denoted by $A / J$ and reads $A$ mod $J$. Then, $A / J$ with coset addition and multiplication is a ring.

An ideal $J$ of a commutative ring is said to be a **prime ideal** if for any two elements $a$ and $b$ in the ring,
$$
ab \in J \implies a \in J \text{ or } b \in J
$$
<u>Theorem:</u> If $J$ is a prime ideal of a community ring with unity $A$, then the quotient ring $A / J$ is an integral domain.

An ideal $J$ of $A$ with $J \ne A$ is called a **maximal ideal** if there exists no proper ideal $K$ of $A$ such that $J \subseteq K$ with $J \ne K$.

<u>Theorem:</u> If $A$ is a commutative ring with unity, then $J$ is a maximal ideal of $A$ iff $A/J$ is a field.

